Struct ZwlrExportDmabufFrameV1
pub struct ZwlrExportDmabufFrameV1 { /* private fields */ }wayland and Linux only.Expand description
a DMA-BUF frame
This object represents a single DMA-BUF frame.
If the capture is successful, the compositor will first send a “frame” event, followed by one or several “object”. When the frame is available for readout, the “ready” event is sent.
If the capture failed, the “cancel” event is sent. This can happen anytime before the “ready” event.
Once either a “ready” or a “cancel” event is received, the client should destroy the frame. Once an “object” event is received, the client is responsible for closing the associated file descriptor.
All frames are read-only and may not be written into or altered.
See also the Event enum for this interface.
Implementations
impl ZwlrExportDmabufFrameV1
impl ZwlrExportDmabufFrameV1
pub fn destroy(&self)
pub fn destroy(&self)
delete this object, used or not
Unreferences the frame. This request must be called as soon as its no longer used.
It can be called at any time by the client. The client will still have to close any FDs it has been given.